    /**
     * Prompt dialog object
     *
	 * invoked by:
	 *	alertify.prompt(message);
	 *	alertify.prompt(message, value);
	 *	alertify.prompt(message, value, onok);
	 *	alertify.prompt(message, value, onok, oncancel);
	 *	alertify.prompt(title, message, value, onok, oncancel);
	 */
    alertify.dialog('prompt',function(){
        var input = document.createElement('INPUT');
		var p = document.createElement('P');
        return {
            main:function(_title, _message, _value , _onok, _oncancel){
				var title, message,value, onok, oncancel;
				switch(arguments.length){
                case 1:
                    message	= _title;
                    break;
                case 2:
					message	= _title;
                    value	= _message;
                    break;
                case 3:
                    message	= _title;
                    value	= _message;
                    onok	= _value;
                    break;
				case 4:
                    message	= _title;
					value	= _message;
					onok	= _value;
					oncancel= _onok;
                    break;
				case 4:
					title	= _title;
                    message	= _message;
					value	= _value;
					onok	= _onok;
					oncancel= _oncancel;
                    break;
                }
                this.setting('title', title);
				this.setting('message', message);
				this.setting('value', value);
				this.setting('onok', onok);
				this.setting('oncancel', oncancel);
                return this;
            },
			setup:function(){
				return {
					buttons:[
						{
							text: alertify.defaults.glossary.ok,
							key: keys.ENTER,
							className: alertify.defaults.theme.ok,
						},
						{
							text: alertify.defaults.glossary.cancel,
							key: keys.ESC,
							invokeOnClose: true,
							className: alertify.defaults.theme.cancel,
						}
					],
					focus:{
						element: input,
						select: true
					},
					options:{
						maximizable:false,
						resizable:false
					}
				};
			},
            build:function(){
                input.className = alertify.defaults.theme.input;
                input.setAttribute('type','text');
                input.value = this.settings.value;
				this.elements.content.appendChild(p);
                this.elements.content.appendChild(input);
            },
            prepare:function(){
				//nothing
            },
			setMessage:function(message){
				if(typeof message === 'string'){
                    p.innerHTML = message;
                }else if (message instanceof window.HTMLElement && p.firstChild !== message){
                    p.innerHTML = '';
                    p.appendChild(message);
                }
			},
			settings:{
				message:undefined,
				labels:undefined,
				onok:undefined,
				oncancel:undefined,
				value:'',
				reverseButtons:undefined,
			},
            settingUpdated:function(key, oldValue, newValue){
                switch(key){
                case 'message':
                    this.setMessage(newValue);
                    break;
                case 'value':
                    input.value = newValue;
                    break;
                case 'labels':
                    if(newValue.ok && this.__internal.buttons[0].element){
                        this.__internal.buttons[0].element.innerHTML = newValue.ok;
                    }
                    if(newValue.cancel && this.__internal.buttons[1].element){
                        this.__internal.buttons[1].element.innerHTML = newValue.cancel;
                    }
                    break;
                case 'reverseButtons':
                    if(newValue === true){
                        this.elements.buttons.primary.appendChild(this.__internal.buttons[0].element);
                    }else{
                        this.elements.buttons.primary.appendChild(this.__internal.buttons[1].element);
                    }
                    break;
                }
			},
            callback:function(closeEvent){
                var returnValue;
                switch(closeEvent.index){
                case 0:
                    this.value = input.value;
                    if(typeof this.settings.onok === 'function'){
                        returnValue = this.settings.onok.call(undefined, closeEvent, this.value);
                        if(typeof returnValue !== 'undefined'){
                            closeEvent.cancel = !returnValue;
                        }
                    }
                    break;
                case 1:
                    if(typeof this.settings.oncancel === 'function'){
                        returnValue = this.settings.oncancel.call(undefined, closeEvent);
                        if(typeof returnValue !== 'undefined'){
                            closeEvent.cancel = !returnValue;
                        }
                    }
                    break;
                }
            }
		};
    });